@@ -2,4 +2,7 @@
 
 __author__ = """Ramendra Sahoo"""
 __email__ = 'ramendrageo@gmail.com'
-__version__ = '0.0.2'
+__version__ = '0.0.5'
+
+from .geodemora import *
+from .utils import *
\ No newline at end of file
